@@ -149,6 +149,9 @@
 #if defined(MEDIAINFO_AVSV_YES)
     #include "MediaInfo/Video/File_AvsV.h"
 #endif
+#if defined(MEDIAINFO_AVS3V_YES)
+    #include "MediaInfo/Video/File_Avs3V.h"
+#endif
 #if defined(MEDIAINFO_DIRAC_YES)
     #include "MediaInfo/Video/File_Dirac.h"
 #endif
@@ -158,6 +161,9 @@
 #if defined(MEDIAINFO_H263_YES)
     #include "MediaInfo/Video/File_H263.h"
 #endif
+#if defined(MEDIAINFO_MXF_YES)
+    #include "MediaInfo/Video/File_HdrVividMetadata.h"
+#endif
 #if defined(MEDIAINFO_HEVC_YES)
     #include "MediaInfo/Video/File_Hevc.h"
 #endif
@@ -224,6 +230,9 @@
 #if defined(MEDIAINFO_DTSUHD_YES)
     #include "MediaInfo/Audio/File_DtsUhd.h"
 #endif
+#if defined(MEDIAINFO_DAT_YES)
+    #include "MediaInfo/Audio/File_Dat.h"
+#endif
 #if defined(MEDIAINFO_DOLBYE_YES)
     #include "MediaInfo/Audio/File_DolbyE.h"
 #endif
@@ -287,6 +296,9 @@
 #if defined(MEDIAINFO_N19_YES)
     #include "MediaInfo/Text/File_N19.h"
 #endif
+#if defined(MEDIAINFO_PAC_YES)
+    #include "MediaInfo/Text/File_Pac.h"
+#endif
 #if defined(MEDIAINFO_PDF_YES)
     #include "MediaInfo/Text/File_Pdf.h"
 #endif
@@ -559,6 +571,9 @@ File__MultipleParsing::File__MultipleParsing()
     #if defined(MEDIAINFO_AVC_YES)
         Parser.push_back(new File_Avc());
     #endif
+    #if defined(MEDIAINFO_MXF_YES)
+        Parser.push_back(new File_HdrVividMetadata());
+    #endif
     #if defined(MEDIAINFO_HEVC_YES)
         Parser.push_back(new File_Hevc());
     #endif
@@ -637,6 +652,10 @@ File__MultipleParsing::File__MultipleParsing()
         Parser.push_back(new File_DtsUhd());
     #endif
 //    Too many false-positives
+//    #if defined(MEDIAINFO_DAT_YES)
+//        Parser.push_back(new File_Dat());
+//    #endif
+//    Too many false-positives
 //    #if defined(MEDIAINFO_DOLBYE_YES)
 //        Parser.push_back(new File_DolbyE());
 //    #endif
@@ -694,6 +713,9 @@ File__MultipleParsing::File__MultipleParsing()
     #if defined(MEDIAINFO_N19_YES)
         Parser.push_back(new File_N19());
     #endif
+    #if defined(MEDIAINFO_PAC_YES)
+        Parser.push_back(new File_Pac());
+    #endif
     #if defined(MEDIAINFO_PDF_YES)
         Parser.push_back(new File_Pdf());
     #endif
