@@ -47,6 +47,7 @@ class File_Mpeg4 : public File__Analyze, File__HasReferences
 protected :
     //Streams management
     void Streams_Accept();
+    void Streams_Accept_jp2(bool IsJp2=false);
     void Streams_Finish();
     void Streams_Finish_CommercialNames ();
 
@@ -216,7 +217,7 @@ private :
     void moov_trak_mdia_minf_stbl_stsd_xxxxSound();
     void moov_trak_mdia_minf_stbl_stsd_xxxxText();
     void moov_trak_mdia_minf_stbl_stsd_xxxxVideo();
-    void moov_trak_mdia_minf_stbl_stsd_xxxxOthers();
+    void moov_trak_mdia_minf_stbl_stsd_xxxxOthers(const string& CodecIDAddition);
     void moov_trak_mdia_minf_stbl_stsd_xxxx_alac();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_AALP();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_ACLR();
@@ -369,6 +370,8 @@ private :
     void moov_udta_rtng();
     void moov_udta_ptv ();
     void moov_udta_Sel0();
+    void moov_udta_smta();
+    void moov_udta_smta_mdln();
     void moov_udta_tags();
     void moov_udta_tags_meta();
     void moov_udta_tags_tseg();
@@ -489,6 +492,15 @@ private :
             bool   NegativeTimes;
         };
         timecode* TimeCode;
+        struct nclc
+        {
+            int8u  colour_primaries;
+            int8u  transfer_characteristics;
+            int8u  matrix_coefficients;
+            bool   HasFlags;
+            bool   full_range_flag;
+        };
+        nclc* Nclc;
         stream_t                StreamKind;
         size_t                  StreamPos;
         int32u                  hdlr_Type;
@@ -606,6 +618,7 @@ private :
         {
             MI=NULL;
             TimeCode=NULL;
+            Nclc=NULL;
             StreamKind=Stream_Max;
             StreamPos=(size_t)-1;
             hdlr_Type=0x00000000;
@@ -677,6 +690,7 @@ private :
                 delete Parsers[Pos];
             delete MI; //MI=NULL;
             delete TimeCode; //TimeCode=NULL;
+            delete Nclc; //Nclc=NULL;
         }
 
         void Parsers_Clear()
